@@ -1,6 +1,6 @@
 /************************************************************************
  **
- **  Copyright (C) 2020-2021 Kevin B. Hendricks, Stratford Ontario Canada
+ **  Copyright (C) 2020-2024 Kevin B. Hendricks, Stratford Ontario Canada
  **
  **  This file is part of Sigil.
  **
@@ -84,6 +84,7 @@ CPCompare::CPCompare(const QString& bookroot,
     setWindowTitle(tr("Results of Comparison"));
     m_bp->setText(tr("Done"));
     m_bp->setToolButtonStyle(Qt::ToolButtonTextOnly);
+    m_bp->setFocusPolicy(Qt::TabFocus);
     QHBoxLayout *hl = new QHBoxLayout();
     hl->addWidget(m_dlist);
     hl->addWidget(m_alist);
@@ -111,7 +112,7 @@ void CPCompare::handle_del_request()
             sv->show();
             sv->raise();
         } else if (IMAGE_EXTENSIONS.contains(ext)) {
-            ViewImage * vi = new ViewImage(this);
+            ViewImage * vi = new ViewImage(this, true);
             vi->ShowImage(filepath);
             vi->show();
             vi->raise();
@@ -145,7 +146,7 @@ void CPCompare::handle_add_request()
             sv->show();
             sv->raise();
         } else if (IMAGE_EXTENSIONS.contains(ext)) {
-            ViewImage * vi = new ViewImage(this);
+            ViewImage * vi = new ViewImage(this, true);
             vi->ShowImage(filepath);
             vi->show();
             vi->raise();
@@ -179,11 +180,7 @@ void CPCompare::handle_mod_request()
 
             QApplication::setOverrideCursor(Qt::WaitCursor);
             QFuture<QList<DiffRecord::DiffRec>> bfuture =
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-                QtConcurrent::run(&pr, &PythonRoutines::GenerateParsedNDiffInPython, leftpath, rightpath);
-#else
                 QtConcurrent::run(&PythonRoutines::GenerateParsedNDiffInPython, &pr, leftpath, rightpath);
-#endif
             bfuture.waitForFinished();
             QList<DiffRecord::DiffRec> diffinfo = bfuture.result();
             QApplication::restoreOverrideCursor();
