@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2019 Kevin B. Hendricks Stratford, ON, Canada 
+**  Copyright (C) 2015-2024 Kevin B. Hendricks Stratford, ON, Canada 
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -27,6 +27,7 @@
 #include "BookManipulation/Book.h"
 #include "BookManipulation/FolderKeeper.h"
 #include "BookManipulation/XhtmlDoc.h"
+#include "BookManipulation/CleanSource.h"
 #include "Dialogs/HeadingSelector.h"
 #include "Parsers/GumboInterface.h"
 #include "Misc/SettingsStore.h"
@@ -265,7 +266,8 @@ void HeadingSelector::UpdateHeadingElements()
             m_book_changed = true;
             if (!changed_resources.contains(heading->resource_file)) {
                 QString source = heading->resource_file->GetTOCCache();
-                heading->resource_file->SetText(source);
+                QString version = heading->resource_file->GetEpubVersion();
+                heading->resource_file->SetText(CleanSource::CharToEntity(source, version));
                 changed_resources.append(heading->resource_file);
             }
         }
@@ -439,7 +441,7 @@ void HeadingSelector::UpdateOneHeadingTitle(QStandardItem *item, const QString &
                 gumbo_element_set_attribute(element, "title", title.toUtf8().constData());
             }
             source = gi.getxhtml();
-            heading->resource_file->SetText(source);
+            heading->resource_file->SetText(CleanSource::CharToEntity(source, version));
         }
     }
 }
@@ -500,7 +502,7 @@ void HeadingSelector::ChangeHeadingLevel(int change_amount)
         if (HEADING_LOOKUP.contains(old_tag)) {
             node->v.element.tag = new_tag;
             source = gi.getxhtml();
-            heading->resource_file->SetText(source);
+            heading->resource_file->SetText(CleanSource::CharToEntity(source, version));
         }
     }
     // Clear all children information then rebuild hierarchy
@@ -835,7 +837,11 @@ int HeadingSelector::GetMaxHeadingLevel(QList<Headings::Heading> flat_headings)
 // Add the selectable entries to the Select Heading combo box
 void HeadingSelector::PopulateSelectHeadingCombo(int max_heading_level)
 {
+    disconnect(ui.cbTOCSetHeadingLevel, SIGNAL(currentTextChanged(const QString &)),
+        this,SLOT(SelectHeadingLevelInclusion(const QString &)));
+
     QString entry = tr("Up to level");
+
     ui.cbTOCSetHeadingLevel->clear();
     ui.cbTOCSetHeadingLevel->addItem(tr("<Select headings to include in TOC>"));
 
@@ -848,8 +854,11 @@ void HeadingSelector::PopulateSelectHeadingCombo(int max_heading_level)
 
         ui.cbTOCSetHeadingLevel->addItem(tr("All"));
     }
+    connect(ui.cbTOCSetHeadingLevel, SIGNAL(currentTextChanged(const QString &)),
+            this,SLOT(SelectHeadingLevelInclusion(const QString &)));
 }
 
+
 void HeadingSelector::RefreshTOCModelDisplay()
 {
     CreateTOCModel();
@@ -907,7 +916,13 @@ void HeadingSelector::SelectHeadingLevelInclusion(const QString &heading_level)
 
     // else is "<Select heading level>" which does nothing
     // Reset selection to description
+       // the toolbutton will NOT take ownership of the menu as per the Qt docs
+    // so clean up manually
+    disconnect(ui.cbTOCSetHeadingLevel, SIGNAL(currentTextChanged(const QString &)),
+            this,SLOT(SelectHeadingLevelInclusion(const QString &)));
     ui.cbTOCSetHeadingLevel->setCurrentIndex(0);
+    connect(ui.cbTOCSetHeadingLevel, SIGNAL(currentTextChanged(const QString &)),
+            this,SLOT(SelectHeadingLevelInclusion(const QString &)));
 }
 
 
@@ -1024,23 +1039,16 @@ void HeadingSelector::ConnectSignalsToSlots()
     connect(this,               SIGNAL(accepted()),
             this,               SLOT(UpdateHeadingElements())
            );
-    #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect(ui.cbTOCSetHeadingLevel,
-            SIGNAL(activated(const QString &)),
+            SIGNAL(currentTextChanged(const QString &)),
             this,               SLOT(SelectHeadingLevelInclusion(const QString &))
            );
-    #else
-    connect(ui.cbTOCSetHeadingLevel,
-            SIGNAL(textActivated(const QString &)),
-            this,               SLOT(SelectHeadingLevelInclusion(const QString &))
-           );
-    #endif
-    connect(ui.left,             SIGNAL(clicked()), this, SLOT(DecreaseHeadingLevel()));
-    connect(ui.right,            SIGNAL(clicked()), this, SLOT(IncreaseHeadingLevel()));
-    connect(ui.rename,           SIGNAL(clicked()), this, SLOT(Rename()));
-    connect(ui.tvTOCDisplay,     SIGNAL(customContextMenuRequested(const QPoint &)),
-            this,                SLOT(OpenContextMenu(const QPoint &)));
-    connect(m_Rename,            SIGNAL(triggered()), this, SLOT(Rename()));
+    connect(ui.bleft,           SIGNAL(clicked()), this, SLOT(DecreaseHeadingLevel()));
+    connect(ui.bright,          SIGNAL(clicked()), this, SLOT(IncreaseHeadingLevel()));
+    connect(ui.rename,          SIGNAL(clicked()), this, SLOT(Rename()));
+    connect(m_Rename,           SIGNAL(triggered()), this, SLOT(Rename()));
+    connect(ui.tvTOCDisplay,    SIGNAL(customContextMenuRequested(const QPoint &)),
+            this,               SLOT(OpenContextMenu(const QPoint &)));
 }
 
 
