@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2015-2024 Kevin B. Hendricks, Stratford, Ontario, Canada
 **  Copyright (C) 2013      Dave Heiland
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
@@ -62,6 +62,7 @@ void SpellCheckWidget::setUpTable()
     ui.userDictList->setSelectionBehavior(QAbstractItemView::SelectRows);
     ui.userDictList->setSelectionMode(QAbstractItemView::SingleSelection);
     ui.userDictList->setAlternatingRowColors(true);
+    ui.userDictList->setTabKeyNavigation(false);
 }
 
 PreferencesWidget::ResultActions SpellCheckWidget::saveSettings()
@@ -130,7 +131,7 @@ void SpellCheckWidget::addUserDict()
     }
 
     if (currentDicts.contains(name, Qt::CaseInsensitive)) {
-        QMessageBox::critical(this, tr("Error"), tr("A user dictionary already exists with this name!"));
+        Utility::critical(this, tr("Error"), tr("A user dictionary already exists with this name!"));
         return;
     }
 
@@ -170,7 +171,7 @@ bool SpellCheckWidget::createUserDict(QString dict_name)
     if (dict_file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
         dict_file.close();
     } else {
-        QMessageBox::critical(this, tr("Error"), tr("Could not create file!"));
+        Utility::critical(this, tr("Error"), tr("Could not create file!"));
         return false;
     }
 
@@ -232,7 +233,7 @@ void SpellCheckWidget::renameUserDict()
     }
 
     if (currentDicts.contains(new_name)) {
-        QMessageBox::critical(this, tr("Error"), tr("A user dictionary already exists with this name!"));
+        Utility::critical(this, tr("Error"), tr("A user dictionary already exists with this name!"));
         return;
     }
 
@@ -240,7 +241,7 @@ void SpellCheckWidget::renameUserDict()
     QString new_path = SpellCheck::userDictionaryDirectory() + "/" + new_name;
 
     if (!Utility::RenameFile(orig_path, new_path)) {
-        QMessageBox::critical(this, tr("Error"), tr("Could not rename file!"));
+        Utility::critical(this, tr("Error"), tr("Could not rename file!"));
         return;
     }
 
@@ -259,7 +260,7 @@ void SpellCheckWidget::removeUserDict()
 
     // Don't remove the last dictionary
     if (m_Model.rowCount() == 1) {
-        QMessageBox::warning(this, tr("Error"), tr("You cannot delete the last dictionary."));
+        Utility::warning(this, tr("Error"), tr("You cannot delete the last dictionary."));
         return;
     }
 
@@ -472,9 +473,6 @@ void SpellCheckWidget::loadUserDictionaryWordList(QString dict_name)
 
     if (userDictFile.open(QIODevice::ReadOnly)) {
         QTextStream userDictStream(&userDictFile);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        userDictStream.setCodec("UTF-8");
-#endif
         QString line;
 
         do {
@@ -525,9 +523,6 @@ void SpellCheckWidget::saveUserDictionaryWordList(QString dict_name)
 
     if (userDictFile.open(QFile::WriteOnly | QFile::Truncate)) {
         QTextStream userDictStream(&userDictFile);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        userDictStream.setCodec("UTF-8");
-#endif
         foreach(QString word, words) {
             userDictStream << word << "\n";
         }
