@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019 Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2019-2021 Kevin B. Hendricks, Stratford, Ontario, Canada
 **  Copyright (C) 2012 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012 Dave Heiland
 **
@@ -29,6 +29,7 @@
 #include <QtWidgets/QDialog>
 #include <QtGui/QStandardItemModel>
 #include <QtCore/QSharedPointer>
+#include <QString>
 
 #include "ResourceObjects/Resource.h"
 #include "BookManipulation/Book.h"
@@ -37,8 +38,6 @@
 
 #include "ui_ReportsCharactersInHTMLFilesWidget.h"
 
-class QString;
-
 class CharactersInHTMLFilesWidget : public ReportsWidget
 {
     Q_OBJECT
@@ -51,8 +50,8 @@ public:
 
 signals:
     void CloseDialog();
-    void OpenFileRequest(QString, int);
-    void FindText(QString);
+    void OpenFileRequest(QString, int, int);
+    void FindSpecifiedText(QString);
 
 private slots:
     void FilterEditTextChangedSlot(const QString &text);
@@ -69,7 +68,7 @@ private:
     void SetupTable();
     void AddTableData();
 
-    QList <QChar> GetDisplayedCharacters(QList<HTMLResource *> resources);
+    QList <uint> GetDisplayedCharacters(QList<HTMLResource *> resources);
 
     QSharedPointer<Book> m_Book;
 
