@@ -113,7 +113,7 @@ void HTMLFilesWidget::SetupTable(int sort_column, Qt::SortOrder sort_order)
         // File Size
         double ffsize = QFile(path).size() / 1024.0;
         total_size += ffsize;
-        QString fsize = QString::number(ffsize, 'f', 2);
+        QString fsize = QLocale().toString(ffsize, 'f', 2);
         NumericItem *size_item = new NumericItem();
         size_item->setText(fsize);
         size_item->setTextAlignment(Qt::AlignRight);
@@ -352,7 +352,7 @@ void HTMLFilesWidget::Save()
     try {
         Utility::WriteUnicodeTextFile(data, destination);
     } catch (CannotOpenFile&) {
-        QMessageBox::warning(this, tr("Sigil"), tr("Cannot save report file."));
+        Utility::warning(this, tr("Sigil"), tr("Cannot save report file."));
     }
 
     m_LastDirSaved = QFileInfo(destination).absolutePath();
