@@ -259,8 +259,6 @@ void SpellcheckEditor::CreateModel(int sort_column, Qt::SortOrder sort_order)
     header.append(tr("Count"));
     header.append(tr("Language"));
     header.append(tr("Misspelled?"));
-    m_SpellcheckEditorModel->setHorizontalHeaderLabels(header);
-    ui.SpellcheckEditorTree->header()->setSectionResizeMode(0, QHeaderView::Stretch);
 
     QHash<QString, int> unique_words = m_Book->GetUniqueWordsInHTMLFiles();
 
@@ -303,9 +301,11 @@ void SpellcheckEditor::CreateModel(int sort_column, Qt::SortOrder sort_order)
         NumericItem *count_item = new NumericItem();
         count_item->setText(QString::number(count));
         count_item->setTextAlignment(Qt::AlignRight);
+        count_item->setEditable(false);
         row_items << count_item;
 
         QStandardItem *lang_item = new QStandardItem(lang);
+        lang_item->setEditable(false);
         row_items << lang_item;
 
         QStandardItem *misspelled_item = new QStandardItem();
@@ -325,6 +325,9 @@ void SpellcheckEditor::CreateModel(int sort_column, Qt::SortOrder sort_order)
     ui.SpellcheckEditorTree->resizeColumnToContents(2);
     ui.SpellcheckEditorTree->resizeColumnToContents(3);
 
+    m_SpellcheckEditorModel->setHorizontalHeaderLabels(header);
+    ui.SpellcheckEditorTree->header()->setSectionResizeMode(0, QHeaderView::Stretch);
+
     // Changing the sortIndicator order should not cause the entire wordlist to be regenerated
     // disconnect(ui.SpellcheckEditorTree->header(), SIGNAL(sortIndicatorChanged(int, Qt::SortOrder)), this, SLOT(Sort(int, Qt::SortOrder)));
 
