@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Modifications Copyright (C) 2016-2021 Kevin B, Hendricks, Stratford, ON, Canada
+** Modifications Copyright (C) 2016-2024 Kevin B, Hendricks, Stratford, ON, Canada
 **
 ** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
@@ -131,11 +131,7 @@ bool TreeItem::moveChildUp(int position)
     if (position <=0 || position > childItems.size() - 1)
         return false;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    childItems.swap(position, position-1);
-#else
     childItems.swapItemsAt(position, position-1);
-#endif
     return true;
 }
 
@@ -144,11 +140,7 @@ bool TreeItem::moveChildDown(int position)
     if (position < 0 || position >= childItems.size() - 1)
         return false;
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    childItems.swap(position, position+1);
-#else
     childItems.swapItemsAt(position, position+1);
-#endif
     return true;
 }
 
