@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019-2023 Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2019-2025 Kevin B. Hendricks, Stratford, Ontario, Canada
 **
 **  This file is part of Sigil.
 **
@@ -22,7 +22,14 @@
 #include <QString>
 #include <QStringList>
 #include <QHash>
+#include <QFileInfo>
+#include <QFile>
+#include <QMimeDatabase>
+#include <QMimeType>
+
 #include "sigil_constants.h"
+#include "Misc/Utility.h"
+#include "Parsers/QuickParser.h"
 #include "Misc/MediaTypes.h"
 
 const QStringList IMAGE_EXTENSIONS     = QStringList() << "jpg"   << "jpeg" << "png" << "gif"  << "tif"  << "tiff"  << "bm"
@@ -32,7 +39,7 @@ const QStringList SMIL_EXTENSIONS      = QStringList() << "smil";
 const QStringList JPG_EXTENSIONS       = QStringList() << "jpg"   << "jpeg";
 const QStringList TIFF_EXTENSIONS      = QStringList() << "tif"   << "tiff";
 const QStringList MISC_TEXT_EXTENSIONS = QStringList() << "txt"   << "js";
-const QStringList MISC_XML_EXTENSIONS  = QStringList() << "smil"  << "xpgt" << "pls";
+const QStringList MISC_XML_EXTENSIONS  = QStringList() << "smil"  << "xpgt" << "pls" "xml";
 const QStringList FONT_EXTENSIONS      = QStringList() << "ttf"   << "ttc"  << "otf" << "woff" << "woff2";
 const QStringList TEXT_EXTENSIONS      = QStringList() << "xhtml" << "html" << "htm";
 const QStringList STYLE_EXTENSIONS     = QStringList() << "css";
@@ -53,7 +60,9 @@ const QStringList MISC_XML_MIMETYPES   = QStringList() << "application/oebps-pag
                                                        << "application/smil+xml" 
                                                        << "application/adobe-page-template+xml" 
                                                        << "application/vnd.adobe-page-template+xml" 
-                                                       << "application/pls+xml";
+                                                       << "application/pls+xml"
+                                                       << "application/xml"
+                                                       << "text/xml";
 
 
 MediaTypes *MediaTypes::m_instance = 0;
@@ -73,6 +82,75 @@ QString MediaTypes::GetMediaTypeFromExtension(const QString &extension, const QS
     return m_ExtToMType.value(extension, fallback);
 }
 
+
+QString MediaTypes::GetFileDataMimeType(const QString &absolute_file_path, const QString &fallback)
+{
+    QMimeDatabase db;
+    QString mimetype = fallback;
+    QFileInfo fi(absolute_file_path);
+    QFile file(absolute_file_path);
+    if (file.open(QIODeviceBase::ReadOnly)) {
+        QMimeType mt = db.mimeTypeForFileNameAndData(fi.fileName(), &file);
+        if (mt.isValid()) {
+            mimetype = mt.name();
+	}
+        file.close();
+    }
+    return mimetype;
+}
+
+
+QString MediaTypes::GetMediaTypeFromXML(const QString& absolute_file_path, const QString &fallback)
+{
+    QString mimetype = fallback;
+    QString xmldata = Utility::ReadUnicodeTextFile(absolute_file_path);
+    QuickParser qp(xmldata);
+    while(true) {
+        QuickParser::MarkupInfo mi = qp.parse_next();
+        if (mi.pos < 0) break;
+        if (mi.text.isEmpty()) {
+            if (mi.ttype == "begin" || mi.ttype == "single") {
+                mimetype = "application/xml";
+                QString tag = mi.tname;
+                QString prefix = "";
+                if (mi.tname.contains(":")) {
+                    QStringList tagpieces = mi.tname.split(':');
+                    tag = tagpieces.at(1);
+                    prefix = tagpieces.at(0);
+                }
+                QStringList attvalues = mi.tattr.values();
+                if (tag == "smil" && attvalues.contains("http://www.w3.org/ns/SMIL")) {
+                    mimetype = "application/smil+xml";
+                }
+                if (tag == "template" && attvalues.contains("http://ns.adobe.com/2006/ade")) {
+                    mimetype = "application/vnd.adobe-page-template+xml";
+                }
+                if (tag == "page-map")        mimetype = "application/vnd.adobe-page-map+xml";
+                if (tag == "display_options") mimetype = "application/apple-display-options+xml";
+                if (tag == "container")       mimetype = "application/oebps-container+xml";
+                if (tag == "svg")             mimetype = "image/svg+xml";
+                if (tag == "package")         mimetype = "application/oebps-package+xml";
+                if (tag == "encryption")      mimetype = "application/oebps-encryption+xml";
+                if (tag == "plist")           mimetype = "application/vnd.apple-plist+xml";
+                if (tag == "onixmessage")     mimetype = "application/onix+xml";
+                if (tag == "tt")              mimetype = "application/ttml+xml";
+                if (tag == "ncx")             mimetype = "application/x-dtbncx+xml";
+                if (tag == "lexicon")         mimetype = "application/pls+xml";
+                if (tag == "html") {
+                    if (attvalues.contains("http://www.w3.org/1999/xhtml")) {
+                        mimetype = "application/xhtml+xml";
+                    } else {
+                        mimetype = "text/html";
+                    }
+                }
+                return mimetype;
+            }
+        }
+    }
+    return mimetype;
+}
+
+
 QString MediaTypes::GetGroupFromMediaType(const QString &media_type, const QString &fallback)
 {
     QString group = m_MTypeToGroup.value(media_type, "");
@@ -162,7 +240,7 @@ void MediaTypes::SetExtToMTypeMap()
     m_ExtToMType[ "woff"  ] = "font/woff";
     m_ExtToMType[ "woff2" ] = "font/woff2";
     m_ExtToMType[ "xhtml" ] = "application/xhtml+xml";
-    m_ExtToMType[ "xml"   ] = "application/oebps-page-map+xml";
+    m_ExtToMType[ "xml"   ] = "application/xml";
     m_ExtToMType[ "xpgt"  ] = "application/vnd.adobe-page-template+xml";
 }
 
@@ -231,14 +309,18 @@ void MediaTypes::SetMTypeToGroupMap()
     m_MTypeToGroup[ "application/smil+xml"                    ] = "Misc";
     m_MTypeToGroup[ "application/pls+xml"                     ] = "Misc";
 
+    m_MTypeToGroup[ "application/xml"                         ] = "Misc";
+    m_MTypeToGroup[ "text/xml"                                ] = "Misc";
+    
     m_MTypeToGroup[ "application/adobe-page-template+xml"     ] = "Misc";
     m_MTypeToGroup[ "application/vnd.adobe-page-template+xml" ] = "Misc";
 
     m_MTypeToGroup[ "application/javascript"                  ] = "Misc";
     m_MTypeToGroup[ "application/ecmascript"                  ] = "Misc";
+    m_MTypeToGroup[ "application/x-javascript"                ] = "Misc";
     m_MTypeToGroup[ "text/javascript"                         ] = "Misc";
-    m_MTypeToGroup[ "application/pdf"                         ] = "Misc";
 
+    m_MTypeToGroup[ "application/pdf"                         ] = "Misc";
 
     m_MTypeToGroup[ "text/plain"                              ] = "Misc";
 
@@ -312,9 +394,13 @@ void MediaTypes::SetMTypeToRDescMap()
     m_MTypeToRDesc[ "application/vnd.adobe-page-template+xml" ] = "XMLResource";  // not a core media type
 
     m_MTypeToRDesc[ "application/javascript"                  ] = "MiscTextResource";
+    m_MTypeToRDesc[ "application/x-javascript"                ] = "MiscTextResource";
     m_MTypeToRDesc[ "application/ecmascript"                  ] = "MiscTextResource";
     m_MTypeToRDesc[ "text/javascript"                         ] = "MiscTextResource";
     m_MTypeToRDesc[ "text/plain"                              ] = "MiscTextResource";  // not a core media type
+    
+    m_MTypeToRDesc[ "application/xml"                         ] = "XMLResource";  // not a core media type
+    m_MTypeToRDesc[ "text/xml"                                ] = "XMLResource";  // not a core media type
 
     m_MTypeToRDesc[ "application/pdf"                         ] = "PdfResource";  // not a core media type
 
