@@ -34,11 +34,7 @@
 
 #include "sigil_constants.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
-static const QString SETTINGS_FILE = SIGIL_SETTINGS_FILE;
-#else
 static const QString SETTINGS_FILE = SIGIL_V6_SETTINGS_FILE;
-#endif
 
 static QString SETTINGS_GROUP = "user_preferences";
 static QString KEY_DEFAULT_METADATA_LANGUAGE = SETTINGS_GROUP + "/" + "default_metadata_lang";
@@ -353,7 +349,7 @@ QStringList SettingsStore::pluginMap()
 QString SettingsStore::defaultVersion()
 {
     clearSettingsGroup();
-    return value(KEY_DEFAULT_VERSION, "2.0").toString();
+    return value(KEY_DEFAULT_VERSION, "3.0").toString();
 }
 
 QList <std::pair <ushort, QString>>  SettingsStore::preserveEntityCodeNames()
