@@ -23,7 +23,7 @@
 #ifndef UILANGUAGE_H
 #define UILANGUAGE_H
 
-class QStringList;
+#include <QStringList>
 
 /**
  * UI Language routines
