@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2023  Kevin B. Hendricks, Stratford Ontario
+**  Copyright (C) 2015-2024  Kevin B. Hendricks, Stratford Ontario
 **
 **  This file is part of Sigil.
 **
@@ -35,25 +35,18 @@
 #include "string_buffer.h"
 #include "error.h"
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
-    #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
-    #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
-#else
-    #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
-    #define QT_ENUM_KEEPEMPTYPARTS QString::KeepEmptyParts
-#endif
-
 static std::unordered_set<std::string> nonbreaking_inline  = { 
     "a","abbr","acronym","b","bdo","big","br","button","cite","code","del",
     "dfn","em","font","i","image","img","input","ins","kbd","label","map",
     "mark", "nobr","object","q","ruby","rt","s","samp","select","small",
     "span","strike","strong","sub","sup","textarea","tt","u","var",
-    "wbr", "mbp:nu"
+    "wbr", "mbp:nu","mi","mn","mo","ms","mspace","mtext","msub","msup",
+    "msubsup"
 };
 
 
 static std::unordered_set<std::string> preserve_whitespace = {
-    "code", "pre","textarea","script","style"
+    "code","cs","pre","textarea","script","style"
 };
 
 
@@ -79,7 +72,10 @@ static std::unordered_set<std::string> void_tags          = {
 static std::unordered_set<std::string> structural_tags     = {
     "article","aside","blockquote","body","canvas","colgroup","div","dl",
     "figure","footer","head","header","hr","html","ol","section",
-    "table","tbody","tfoot","thead","td","th","tr","ul"
+    "table","tbody","tfoot","thead","td","th","tr","ul","math","maction",
+    "annotation","annotation-xml","menclose","mfrac","mmultiscripts",
+    "mover","mpadded","mphantom","mroot","mrow","semantics",
+    "msqrt","mstyle","mtable","mtd","mtr","munder","munderover"
 };
 
 
@@ -526,7 +522,7 @@ QString GumboInterface::get_qwebpath_to_node(GumboNode* node)
 
 GumboNode* GumboInterface::get_node_from_qwebpath(QString webpath) 
 {
-    QStringList path_pieces = webpath.split(",", QT_ENUM_SKIPEMPTYPARTS);
+    QStringList path_pieces = webpath.split(",", Qt::SkipEmptyParts);
     GumboNode* node = get_root_node();
     GumboNode* end_node = node;
     for (int i=0; i < path_pieces.count() - 1 ; ++i) {
