@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # vim:ts=4:sw=4:softtabstop=4:smarttab:expandtab
 
-# Copyright (c) 2014-2020 Kevin B. Hendricks and Doug Massay
+# Copyright (c) 2014-2023 Kevin B. Hendricks and Doug Massay
 # Copyright (c) 2014      John Schember
 # All rights reserved.
 #
@@ -29,10 +29,12 @@
 import sys
 import os
 
-from hrefutils import unquoteurl, buildBookPath, startingDir, longestCommonPath
+from hrefutils import urldecodepart, buildBookPath, startingDir, longestCommonPath
 from hrefutils import mime_group_map
 from collections import OrderedDict
 
+WHITESPACE_CHARS = (' ', '\n', '\r', '\t')
+
 SPECIAL_HANDLING_TAGS = OrderedDict([
     ('?xml', ('xmlheader', -1)),
     ('!--', ('comment', -3)),
@@ -152,6 +154,8 @@ class Opf_Parser(object):
                     self.cover_id = tattr.get("content", None)
                 continue
             # manifest
+            # Note: manifest hrefs when relative may not contain a fragment
+            # as they must refer to and entire file
             if tname == "item" and "manifest" in prefix:
                 nid = "xid%03d" % cnt
                 cnt += 1
@@ -162,13 +166,15 @@ class Opf_Parser(object):
                     mtype = "application/xhtml+xml"
                 if mtype not in mime_group_map:
                     print("****Opf_Parser Warning****: Unknown MediaType: ", mtype)
-                href = unquoteurl(href)
+                # url decode all relative hrefs since no fragment can be present
+                # meaning no ambiguity in the meaning of any # chars in path
+                if href.find(':') == -1:
+                    href = urldecodepart(href)
                 properties = tattr.pop("properties", None)
                 fallback = tattr.pop("fallback", None)
                 overlay = tattr.pop("media-overlay", None)
 
                 # external resources are now allowed in the opf under epub3
-                # we can ignore fragments here as these are links to files
                 self.manifest_id_to_href[id] = href
 
                 bookpath = ""
@@ -206,10 +212,13 @@ class Opf_Parser(object):
                 self.spine.append((idref, linear, properties))
                 continue
             # guide
+            # Note: guide hrefs may have fragments, so leave any
+            # guide hrefs in their raw urlencoded form to prevent
+            # errors
             if tname == "reference" and "guide" in prefix:
                 type = tattr.pop("type", '')
                 title = tattr.pop("title", '')
-                href = unquoteurl(tattr.pop("href", ''))
+                href = tattr.pop("href", '')
                 self.guide.append((type, title, href))
                 continue
             # bindings (stored but ignored for now)
@@ -345,13 +354,13 @@ class Opf_Parser(object):
         if ttype is None:
             # parse any attributes of begin or single tags
             while s.find('=', p) != -1 :
-                while p < n and s[p:p + 1] == ' ' : p += 1
+                while p < n and s[p:p + 1] in WHITESPACE_CHARS : p += 1
                 b = p
                 while p < n and s[p:p + 1] != '=' : p += 1
                 aname = s[b:p].lower()
-                aname = aname.rstrip(' ')
+                aname = aname.rstrip(' \n\r\t')
                 p += 1
-                while p < n and s[p:p + 1] == ' ' : p += 1
+                while p < n and s[p:p + 1] in WHITESPACE_CHARS: p += 1
                 if s[p:p + 1] in ('"', "'") :
                     qt = s[p:p + 1]
                     p = p + 1
